@@ -2,7 +2,7 @@
  *
  * Copyright 1999, 2000  Jochen Voss  */
 
-static const  char  rcsid[] = "$Id: game.c,v 1.35 2000/04/13 20:10:58 voss Rel $";
+static const  char  rcsid[] = "$Id: game.c,v 1.40 2000/11/16 17:57:33 voss Rel $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -14,11 +14,11 @@ static const  char  rcsid[] = "$Id: game.c,v 1.35 2000/04/13 20:10:58 voss Rel $
 
 
 struct mode *game_mode;
-struct mode *pause_mode;
+struct mode *crash_mode;
 
 
 int  crash_detected;		/* a crash is in progress */
-static  int  level;		/* the current level (pause_mode only) */
+static  int  level;		/* the current level (crash_mode only) */
 static  int  lives;		/* cars left (including the current one) */
 static  int  score;		/* points we already got */
 int  stakes;			/* points to get, when we reach the ground */
@@ -45,12 +45,6 @@ print_lives (void)
  * game mode
  */
 
-static void
-setup_screen (void)
-{
-  resize_ground (1);
-}
-
 void
 print_game_over (int blink)
 {
@@ -75,7 +69,6 @@ game_enter (int seed)
     lives = 3;
     werase (status);
     wnoutrefresh (status);
-    setup_screen ();
   }
 
   resize_ground (1);
@@ -83,12 +76,7 @@ game_enter (int seed)
 
   crash_detected = 0;
   stakes = 0;
-  print_ground ();
-  print_lives ();
-
   initialise_buggy ();
-  print_buggy ();
-
   start_scrolling (1);
 }
 
@@ -102,7 +90,7 @@ game_leave (void)
 }
 
 static void
-resize_game (void)
+game_redraw (void)
 {
   resize_meteors ();
   resize_laser ();
@@ -127,7 +115,7 @@ key_handler (game_time t, int val)
   case 3:
     lives = 1;
     print_message ("aborted at user's request");
-    mode_change (pause_mode, 0);
+    mode_change (crash_mode, 0);
     break;
   }
 }
@@ -147,62 +135,69 @@ signal_handler (int signum)
   }
 }
 
-void
-leave_pause_mode (game_time t, void *client_data)
+/**********************************************************************
+ * crash mode
+ */
+
+static  int  lives_flag;
+
+static void
+leave_crash_mode (game_time t, void *client_data)
 /* This function is a possible callback argument to `add_event'.
- * It causes the main loop to terminate.
+ * It switch control back to either `game_mode' or `highscore_mode'.
  * The arguments T and CLIENT_DATA are ignored.  */
 {
   if (lives > 0) {
     mode_change (game_mode, 1);
   } else {
-    score_set (score);
-    mode_change (highscore_mode, level+1);
+    score_set (score, level+1);
+    mode_change (highscore_mode, 0);
   }
 }
 
 static void
 print_lives_h (game_time t, void *client_data)
-/* This function is a possible callback argument to `add_event'.
+/* This function is a callback argument to `add_event'.
  * It updates the number of lives display.  */
 {
   print_lives ();
+  lives_flag = 1;
 }
 
 static void
-pause_enter (int seed)
+crash_enter (int seed)
 {
   clock_reset ();
-  add_event (1.5, print_lives_h, NULL);
-  add_event (2.0, leave_pause_mode, NULL);
-  print_ground ();
-  adjust_score (0);
-  print_lives ();
+  lives_flag = 0;
+  add_event (1.2, print_lives_h, NULL);
+  add_event (2.0, leave_crash_mode, NULL);
   print_buggy ();
   if (lives <= 0)  print_game_over (1);
 }
 
 static void
-pause_resize (void)
+crash_redraw (void)
 {
   resize_ground (0);
+  
   print_ground ();
+  print_buggy ();
   adjust_score (0);
-  print_lives ();
+  if (lives_flag)  print_lives ();
 }
 
 static void
-pause_key_handler (game_time t, int val)
+crash_key_handler (game_time t, int val)
 {
   if (t < 0.5)  return;
   
   switch (val) {
   case 1:
-    leave_pause_mode (0, NULL);
+    leave_crash_mode (0, NULL);
     break;
   case 3:
     lives = 0;
-    leave_pause_mode (0, NULL);
+    leave_crash_mode (0, NULL);
     break;
   }
 }
@@ -213,17 +208,19 @@ setup_game_mode (void)
   game_mode = new_mode ();
   game_mode->enter = game_enter;
   game_mode->leave = game_leave;
-  game_mode->redraw = resize_game;
+  game_mode->redraw = game_redraw;
   game_mode->keypress = key_handler;
   game_mode->signal = signal_handler;
   mode_add_key (game_mode, mbk_jump, "jump", 1);
   mode_add_key (game_mode, mbk_fire, "fire", 2);
   mode_add_key (game_mode, mbk_end, "abort game", 3);
+  mode_complete (game_mode);
 
-  pause_mode = new_mode ();
-  pause_mode->enter = pause_enter;
-  pause_mode->redraw = pause_resize;
-  pause_mode->keypress = pause_key_handler;
-  mode_add_key (pause_mode, mbk_start, "continue", 1);
-  mode_add_key (pause_mode, mbk_end, "abort game", 3);
+  crash_mode = new_mode ();
+  crash_mode->enter = crash_enter;
+  crash_mode->redraw = crash_redraw;
+  crash_mode->keypress = crash_key_handler;
+  mode_add_key (crash_mode, mbk_start, "continue", 1);
+  mode_add_key (crash_mode, mbk_end, "abort game", 3);
+  mode_complete (crash_mode);
 }
