@@ -1,8 +1,8 @@
 /* highscore.c - maintain the highscore list
  *
- * Copyright 1999, 2000  Jochen Voss  */
+ * Copyright 1999, 2000, 2001  Jochen Voss  */
 
-static const  char  rcsid[] = "$Id: highscore.c,v 1.36.2.2 2000/05/06 15:52:28 voss Exp $";
+static const  char  rcsid[] = "$Id: highscore.c,v 1.43 2001/08/26 20:42:14 voss Rel $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -128,19 +128,16 @@ merge_entry (const struct score_entry *entry)
 
 static void
 randomize_entry (int n)
-/* Fill slot N of `highscore' with a random entry.
- * Set `highscore_changed' to 1 if the table is changed.   */
+/* Fill slot N of `highscore' with a random entry.   */
 {
   static const char *names [13] = {
     "Dwalin", "Balin", "Kili", "Fili", "Dori", "Nori", "Ori",
     "Oin", "Gloin", "Bifur", "Bofur", "Bombur", "Thorin"
   };
-  time_t  yesterday;
 
-  yesterday = time (NULL) - 24*60*60;
   highscore[n].score = 10*(HIGHSCORE_SLOTS-n);
   highscore[n].level = 1;
-  highscore[n].date = yesterday;
+  highscore[n].date = time (NULL);
   strcpy (highscore[n].name, names[uniform_rnd(13)]);
   highscore[n].new = 0;
 
@@ -149,7 +146,7 @@ randomize_entry (int n)
 
 static time_t
 expire_date (int rank, time_t date)
-/* Calculate the expiration date for an entry, which is at rank RANK
+/* Calculate the expiration date for an entry, which is at position RANK
  * and which was entered at DATE.  */
 {
   /* linear interpolation: rank 3 expires after 180 days, the last one
@@ -157,7 +154,7 @@ expire_date (int rank, time_t date)
   double  day = 24*60*60;
   double  rate = (180-14)*day/(HIGHSCORE_SLOTS-4);
 
-  if (rank < 3)  return  date+2000*day;
+  if (rank < 3)  return  time(NULL)+2000*day;
   return  date + 14*day + (HIGHSCORE_SLOTS-1-rank)*rate;
 }
 
@@ -521,22 +518,36 @@ show_highscores (void)
     format_display_date (date, highscore[i].date);
     dt = difftime (expire_date (i, highscore[i].date), now);
     format_relative_time (expire, dt);
-    printf ("%3d    %5u %-3d  %s %s  %." quote(MAX_NAME_CHARS) "s\n",
+    printf ("%3d %8u %-3d  %s %s  %." quote(MAX_NAME_CHARS) "s\n",
 	    i+1, highscore[i].score, highscore[i].level, date, expire,
 	    highscore[i].name);
   }
 }
 
-static int  highscore_valid, last_score;
-static  int  gap;
+static  int  highscore_valid, last_score, last_level;
+static  int  gap;		/* number of omitted entries after pos 3 */
 static  int  max_line;
 
 static void
-center_new (void)
+fix_gap (void)
+/* Cast `gap' to valid value.  */
 {
   int  limit = HIGHSCORE_SLOTS-(max_line-3);
+  if (gap > limit)  gap = limit;
+  if (gap < 2)  gap = 0;
+}
+
+static void
+center_new (void)
+/* Prepare `gap' in order to view values around `last_score'.  */
+{
+  int  limit;
   int  i, pos;
-  
+
+  max_line = LINES-11;
+  if (max_line > 25)  max_line = 25;
+  limit = HIGHSCORE_SLOTS-(max_line-3);
+
   for (i=1; i<HIGHSCORE_SLOTS; ++i) {
     if (highscore[i].score < last_score)  break;
   }
@@ -544,9 +555,7 @@ center_new (void)
 
   pos = 7+(max_line-6)/2;
   gap = 1 + (i+4) - pos;
-
-  if (gap < 2)  gap = 0;
-  if (gap > limit)  gap = limit;
+  fix_gap ();
 }
 
 static void
@@ -582,7 +591,7 @@ print_scores (void)
     format_relative_time (expire, dt);
     if (highscore[i].new)  wstandout (moon);
     mvwprintw (moon, line++, 5,
-	       "%3d    %5u %-3d  %s %s  %." quote(MAX_NAME_CHARS) "s\n",
+	       "%3d %8u %-3d  %s %s  %." quote(MAX_NAME_CHARS) "s\n",
 	       i+1, highscore[i].score, highscore[i].level, date, expire,
 	       highscore[i].name);
     if (highscore[i].new)  wstandend (moon);
@@ -595,19 +604,43 @@ print_scores (void)
 }
 
 void
-score_set (int score)
+score_set (int score, int level)
 {
   last_score = score;
+  last_level = level;
 }
 
 static void
-highscore_enter (int level)
+enter_name_h (game_time t, void *client_data)
+{
+  struct score_entry  entry;
+  int  res;
+    
+  entry.score = last_score;
+  entry.level = last_level;
+  entry.date = time (NULL);
+ retry:
+  entry.name[0] = '\0';
+  res = get_real_user_name (entry.name, MAX_NAME_CHARS);
+  if (res == ERR) {
+    mode_redraw ();
+    goto retry;
+  }
+  entry.new = 1;
+  
+  print_message ("writing score file ...");
+  doupdate ();
+  block_all ();
+  update_score_file (&entry);
+  unblock ();
+  mode_redraw ();
+}
+
+static void
+highscore_enter (int seed)
 {
-  if (level == 0)  last_score = 0;
   print_ground ();
   print_buggy ();
-  max_line = LINES-11;
-  if (max_line > 25)  max_line = 25;
   
   print_message ("loading score file ...");
   doupdate ();
@@ -616,53 +649,21 @@ highscore_enter (int level)
   highscore_valid = 1;
   unblock ();
   center_new ();
-  print_scores ();
 
   if (last_score > highscore[HIGHSCORE_SLOTS-1].score) {
-    struct score_entry  entry;
-    int  res;
-    
-    entry.score = last_score;
-    entry.level = level;
-    entry.date = time (NULL);
-  retry:
-    entry.name[0] = '\0';
-    res = get_real_user_name (entry.name, MAX_NAME_CHARS);
-    if (res == ERR) {
-      mode_redraw ();
-      goto retry;
-    }
-    entry.new = 1;
-  
-    print_message ("writing score file ...");
-    doupdate ();
-    block_all ();
-    update_score_file (&entry);
-    unblock ();
-    center_new ();
-    print_scores ();
+    add_event (0.0, enter_name_h, NULL);
   }
-  mode_keys ();
-  if (level > 0)  print_game_over (1);
 }
 
 static void
 highscore_leave (void)
 {
   print_game_over (0);
-}
-
-static void
-fix_gap (void)
-/* Cast `gap' to valid value.  */
-{
-  int  limit = HIGHSCORE_SLOTS-(max_line-3);
-  if (gap > limit)  gap = limit;
-  if (gap < 2)  gap = 0;
+  last_score = last_level = 0;
 }
 
 void
-resize_highscore (void)
+highscore_redraw (void)
 {
   resize_meteors ();
   resize_ground (0);
@@ -675,6 +676,7 @@ resize_highscore (void)
   adjust_score (0);
   print_lives ();
   print_buggy ();
+  if (last_level > 0)  print_game_over (1);
   if (highscore_valid)  print_scores ();
 }
 
@@ -715,6 +717,16 @@ key_handler (game_time t, int val)
       print_scores ();
     }
     break;
+  case 7:
+    print_message ("reloading score file ...");
+    doupdate ();
+    block_all ();
+    update_score_file (NULL);
+    highscore_valid = 1;
+    unblock ();
+    center_new ();
+    mode_redraw ();
+    break;
   }
 }
 
@@ -724,7 +736,7 @@ setup_highscore_mode (void)
   highscore_mode = new_mode ();
   highscore_mode->enter = highscore_enter;
   highscore_mode->leave = highscore_leave;
-  highscore_mode->redraw = resize_highscore;
+  highscore_mode->redraw = highscore_redraw;
   highscore_mode->keypress = key_handler;
   mode_add_key (highscore_mode, mbk_start, "new game", 1);
   mode_add_key (highscore_mode, mbk_end, "quit", 2);
@@ -732,4 +744,6 @@ setup_highscore_mode (void)
   mode_add_key (highscore_mode, mbk_down, "down", 4);
   mode_add_key (highscore_mode, mbk_pageup, "pg up", 5);
   mode_add_key (highscore_mode, mbk_pagedown, "pg down", 6);
+  mode_add_key (highscore_mode, mbk_scores, "reload", 7);
+  mode_complete (highscore_mode);
 }
