@@ -2,7 +2,7 @@
  *
  * Copyright 1999, 2000  Jochen Voss.  */
 
-static const  char  rcsid[] = "$Id: keyboard.c,v 1.12 2000/04/12 20:24:25 voss Rel $";
+static const  char  rcsid[] = "$Id: keyboard.c,v 1.15 2000/11/01 19:44:33 voss Rel $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -86,7 +86,7 @@ install_keys (void)
   add_key (27, mbk_end, 80);
 
   add_key ('a', mbk_fire, 100);
-  add_key ('l', mbk_fire, 50);
+  add_key ('l', mbk_fire, 60);
 
   add_key ('<', mbk_first, 90);
 #ifdef KEY_HOME
@@ -123,6 +123,9 @@ install_keys (void)
   add_key ('w', mbk_warranty, 100);
 
   add_key ('s', mbk_scores, 100);
+
+  add_key ('r', mbk_redraw, 20);
+  add_key (12, mbk_redraw, 10);	/* \C-l */
 }
 
 int
@@ -138,6 +141,7 @@ read_key (void)
 #ifdef KEY_RESIZE
   if (key_code == KEY_RESIZE)  return -1;
 #endif
+  if (key_code < 256 && isalpha (key_code))  key_code = tolower (key_code);
   entry_p = locate (key_code);
   return  *entry_p ? (*entry_p)->meaning : 0;
 }
