@@ -2,7 +2,7 @@
  *
  * Copyright 1999, 2000  Jochen Voss
  *
- * $Id: moon-buggy.h,v 1.13 2000/04/15 19:50:13 voss Rel $ */
+ * $Id: moon-buggy.h,v 1.20 2000/11/16 17:59:30 voss Rel $ */
 
 #ifndef FILE_MOON_BUGGY_H_SEEN
 #define FILE_MOON_BUGGY_H_SEEN
@@ -31,8 +31,10 @@ extern int  car_base;
 
 extern  void  print_message (const char *str);
 extern  void  print_hint (const char *str);
-extern  void  allocate_windows (void);
+extern  void  prepare_screen (void);
 extern  void  prepare_for_exit (void);
+extern  void  allocate_windows (void);
+extern  void  clear_windows (void);
 
 /* from "queue.c" */
 typedef  double  game_time;
@@ -49,7 +51,6 @@ extern  void  remove_client_data (void *client_data);
 extern  void  clock_freeze (void);
 extern  void  quit_main_loop (void);
 extern  void  main_loop (void);
-extern  void  xsleep (double dt);
 
 extern  void  print_hint_h (game_time t, void *client_data);
 extern  void  clear_hint_h (game_time, void *);
@@ -64,7 +65,7 @@ extern  void  setup_pager_mode (void);
 
 /* from "game.c" */
 extern  struct mode *game_mode;
-extern  struct mode *pause_mode;
+extern  struct mode *crash_mode;
 extern  int  crash_detected;
 extern  int  stakes;
 
@@ -78,7 +79,7 @@ extern  void  level_start (int initial);
 extern  void  level_tick (double t);
 extern  int  current_level (void);
 
-/* from "moon.c" */
+/* from "ground.c" */
 extern  int *bonus;
 extern  char *ground1, *ground2;
 extern  void  resize_ground (int clear_it);
@@ -89,11 +90,11 @@ extern  void  start_scrolling (double t);
 extern  int  car_x, car_y;
 extern  void  initialise_buggy (void);
 extern  void  print_buggy (void);
+extern  void  shift_buggy (int dx);
 extern  void  jump (game_time t);
 extern  int  can_jump (void);
 extern  int  crash_check (void);
-extern  void  shift_buggy (int dx);
-extern  int  car_meteor_hit (game_time t, int x);
+extern  int  car_meteor_hit (int x);
 
 /* from "laser.c" */
 extern  void  fire_laser (double t);
@@ -102,7 +103,8 @@ extern  int  laser_hit (int x);
 extern  void  resize_laser (void);
 
 /* from "meteor.c" */
-extern  void  place_meteor (double t);
+extern  void  scroll_meteors (void);
+extern  void  place_meteor (void);
 extern  void  remove_meteors (void);
 extern  int  meteor_laser_hit (int x0, int x1);
 extern  int  meteor_car_hit (int x0, int x1);
@@ -113,7 +115,7 @@ extern  struct mode *highscore_mode;
 extern  void  create_highscores (void);
 extern  void  show_highscores (void);
 
-extern  void  score_set (int score);
+extern  void  score_set (int score, int level);
 extern  void  setup_highscore_mode (void);
 
 /* from "realname.c" */
@@ -146,7 +148,9 @@ extern  int  handle_signals (void);
 enum mb_key {
   mbk_copyright = 1, mbk_down = 2, mbk_end = 4, mbk_fire = 8, mbk_first = 16,
   mbk_jump = 32, mbk_last = 64, mbk_pagedown = 128, mbk_pageup = 256,
-  mbk_start = 512, mbk_up = 1024, mbk_warranty = 2048, mbk_scores = 4096
+  mbk_start = 512, mbk_up = 1024, mbk_warranty = 2048, mbk_scores = 4096,
+  
+  mbk_redraw = 8192		/* specially handled in `mode_keypress' */
 };
 struct binding {
   int  meanings;
@@ -171,18 +175,19 @@ struct mode {
   void (*keypress) (game_time, int);
 };
 
-extern  void  mode_update (void);
-
 extern  struct mode *new_mode (void);
 extern  void  mode_add_key (struct mode *m,
 			    int meanings, const char *desc, int res);
-extern  void  mode_start (const struct mode *m, int seed);
+extern  void  mode_complete (struct mode *m);
 extern  void  mode_change (const struct mode *m, int seed);
-extern  void  mode_leave (void);
+extern  void  mode_update (void);
 extern  void  mode_redraw (void);
-extern  void  mode_keypress (game_time t);
+extern  int  mode_keypress (game_time t, int meaning);
 extern  void  mode_signal (int signum);
-extern  void  mode_keys (void);
+
+/* from "terminal.c" */
+extern  void  term_prepare (int mesg_n_flag);
+extern  void  term_restore (void);
 
 /* from "cursor.c" */
 extern  void  hide_cursor (void);
