@@ -2,7 +2,7 @@
  *
  * Copyright 1999, 2000  Jochen Voss  */
 
-static const  char  rcsid[] = "$Id: queue.c,v 1.34.2.1 2000/05/05 20:16:15 voss Exp $";
+static const  char  rcsid[] = "$Id: queue.c,v 1.37 2001/08/26 20:56:44 voss Exp $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -17,12 +17,12 @@ static const  char  rcsid[] = "$Id: queue.c,v 1.34.2.1 2000/05/05 20:16:15 voss
 #include <fcntl.h>
 #include <sys/time.h>
 #include <sys/types.h>
-#if HAVE_SYS_SELECT_H
+#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
 #endif
 #include <unistd.h>
 #include <math.h>
-#if HAVE_ERRNO_H
+#ifdef HAVE_ERRNO_H
 #include <errno.h>
 #else
 extern  int  errno;
@@ -321,7 +321,12 @@ main_loop (void)
       retval = 1;
     }
 
-    if (retval>0)  mode_keypress (to_game (t));
+    if (retval>0) {
+      int  meaning = read_key ();
+      if (meaning != -1) {
+	if (! mode_keypress (to_game (t), meaning))  beep ();
+      }
+    }
     
     while (queue && queue->t <= current_time ()) {
       struct event *ev = queue;
