@@ -1,8 +1,8 @@
 /* signal.c - signal handling
  *
- * Copyright 1999, 2000  Jochen Voss.  */
+ * Copyright 1999, 2000, 2001  Jochen Voss.  */
 
-static const  char  rcsid[] = "$Id: signal.c,v 1.16.2.1 2000/05/05 20:15:46 voss Exp $";
+static const  char  rcsid[] = "$Id: signal.c,v 1.21 2001/08/26 20:42:14 voss Rel $";
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -51,11 +51,13 @@ install_signal (int signum, RETSIGTYPE (*handler) ())
 /* Emulate the `signal' function via `sigaction'.  */
 {
   struct sigaction  action;
+  int  ret;
 
   action.sa_handler = handler;
   sigemptyset (&action.sa_mask);
   action.sa_flags = 0;
-  sigaction (signum, &action, NULL);
+  ret = sigaction (signum, &action, NULL);
+  assert (ret == 0);
 }
 
 static RETSIGTYPE
@@ -131,9 +133,7 @@ cont_handler (int signum)
   install_signal (SIGTSTP, tstp_handler);
 
   refresh ();
-  cbreak ();
-  noecho ();
-  hide_cursor ();
+  prepare_screen ();
   mode_redraw ();
   mode_signal (signum);
   clock_thaw ();
@@ -149,8 +149,9 @@ winch_handler (int signum)
   sleep (1);
   endwin ();
   
-  allocate_windows ();
   refresh ();
+  allocate_windows ();
+  hide_cursor ();
   mode_redraw ();
   clock_thaw ();
 }
