@@ -2,7 +2,7 @@
  *
  * Copyright 1999, 2000  Jochen Voss  */
 
-static const  char  rcsid[] = "$Id: title.c,v 1.19 2000/04/08 13:14:14 voss Rel $";
+static const  char  rcsid[] = "$Id: title.c,v 1.22 2000/11/01 13:16:51 voss Rel $";
 
 
 #ifdef HAVE_CONFIG_H
@@ -38,8 +38,8 @@ print_title (void)
 {
   int  title_lines = sizeof (title) / sizeof (const char *);
 
-  waddstr (moon, "  Moon-Buggy version "
-	   VERSION ", Copyright 2000 Jochen Voss\n");
+  mvwaddstr (moon, 0, 0, "  Moon-Buggy version "
+	     VERSION ", Copyright 2000 Jochen Voss\n");
   waddstr (moon, "  Moon-Buggy comes with ABSOLUTELY NO WARRANTY;"
 	   " for details type `w'.\n");
   waddstr (moon,
@@ -56,23 +56,18 @@ print_title (void)
     }
   }
 
-  if (5 + title_lines + 7 <= LINES)  print_buggy ();
+  if (5 + title_lines + 7 <= LINES
+      || 5 + title_lines + 5 > LINES)  print_buggy ();
 
   wnoutrefresh (moon);
 }
 
 static void
-setup_screen (void)
+title_redraw (void)
 {
   resize_ground (1);
-  print_title ();
   print_ground ();
-}
-
-static void
-title_enter (int x)
-{
-  setup_screen ();
+  print_title ();
 }
 
 static void
@@ -101,12 +96,12 @@ void
 setup_title_mode (void)
 {
   title_mode = new_mode ();
-  title_mode->enter = title_enter;
-  title_mode->redraw = setup_screen;
+  title_mode->redraw = title_redraw;
   title_mode->keypress = key_handler;
   mode_add_key (title_mode, mbk_start, "start game", 1);
   mode_add_key (title_mode, mbk_end, "quit", 2);
   mode_add_key (title_mode, mbk_copyright, "show copyright", 3);
   mode_add_key (title_mode, mbk_warranty, "show warranty", 4);
   mode_add_key (title_mode, mbk_scores, "show scores", 5);
+  mode_complete (title_mode);
 }
